@@ -100,8 +100,16 @@ class ForkExec : private boost::noncopyable {
     typedef boost::signals2::signal<void (SyncMLStatus, const std::string &)> OnFailure;
     OnFailure m_onFailure;
 
+    /**
+     * A unique string for the ForkExecParent/Child pair which can be used
+     * as D-Bus path component.
+     */
+    std::string getInstance() const { return m_instance; }
+
  protected:
     ForkExec();
+
+    std::string m_instance;
 };
 
 /**
@@ -118,7 +126,8 @@ class ForkExecParent : public ForkExec
      * will not start the helper yet: first connect your slots, then
      * call start().
      */
-    static boost::shared_ptr<ForkExecParent> create(const std::string &helper);
+    static boost::shared_ptr<ForkExecParent> create(const std::string &helper,
+                                                    const std::vector<std::string> &args = std::vector<std::string>());
 
     /**
      * the helper string passed to create()
@@ -195,9 +204,10 @@ class ForkExecParent : public ForkExec
     void addEnvVar(const std::string &name, const std::string &value);
 
  private:
-    ForkExecParent(const std::string &helper);
+    ForkExecParent(const std::string &helper, const std::vector<std::string> &args);
 
     std::string m_helper;
+    std::vector<std::string> m_args;
     boost::shared_ptr<GDBusCXX::DBusServerCXX> m_server;
     boost::scoped_array<char *> m_argv;
     std::list<std::string> m_argvStrings;
