@@ -43,6 +43,7 @@ typedef void *GMainLoop;
 #include <boost/type_traits/function_traits.hpp>
 #include <boost/utility/value_init.hpp>
 #include <boost/lambda/lambda.hpp>
+#include <boost/typeof/typeof.hpp>
 
 #include <iterator>
 #include <memory>
@@ -239,7 +240,7 @@ template<class C> class TrackGLib : public boost::intrusive_ptr<C> {
     TrackGLib(const TrackGLib &other) : Base_t(other) {}
     operator C * () const { return Base_t::get(); }
     operator bool () const { return Base_t::get() != NULL; }
-    C * ref() const { return static_cast<C *>(g_object_ref(Base_t::get())); }
+    C * ref() const { return static_cast<C *>(intrusive_ptr_add_ref(Base_t::get())); }
 
     static  TrackGLib steal(C *ptr) { return TrackGLib(ptr, TRANSFER_REF); }
 };
@@ -407,7 +408,7 @@ struct GErrorCXX {
     GError *release() { GError *gerror = m_gerror; m_gerror = NULL; return gerror; }
 
     /** checks whether the current error is the one passed as parameters */
-    bool matches(GQuark domain, gint code) { return g_error_matches(m_gerror, domain, code); }
+    bool matches(GQuark domain, gint code) const { return g_error_matches(m_gerror, domain, code); }
 
     /**
      * Use this when passing GErrorCXX instance to C functions which need to set it.
@@ -627,6 +628,7 @@ class PlainGStr : public boost::shared_ptr<gchar>
         PlainGStr(const PlainGStr &other) : boost::shared_ptr<gchar>(other) {}    
         operator const gchar *() const { return &**this; }
         const gchar *c_str() const { return &**this; }
+        void reset(gchar *str) { *this = PlainGStr(str); }
 };
 
 /**
@@ -729,7 +731,7 @@ template<class T, class F, F *finish, class A1, class A3, class A4, class A5> st
             A5_t retval3 = boost::value_initialized<A5_t>();
             T t = finish(reinterpret_cast<A1>(sourceObject),
                          result, &retval1, &retval2, &retval3);
-            std::auto_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
+            std::unique_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
             (*cb)(t, retval1, retval2, retval3);
         } catch (...) {
             // called from C, must not let exception escape
@@ -754,7 +756,7 @@ template<class T, class F, F *finish, class A1, class A3, class A4> struct GAsyn
             A4_t retval2 = boost::value_initialized<A4_t>();
             T t = finish(reinterpret_cast<A1>(sourceObject),
                          result, &retval1, &retval2, gerror);
-            std::auto_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
+            std::unique_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
             (*cb)(t, retval1, retval2, gerror);
         } catch (...) {
             // called from C, must not let exception escape
@@ -778,7 +780,7 @@ template<class T, class F, F *finish, class A1, class A3, class A4> struct GAsyn
             A4_t retval2 = boost::value_initialized<A4_t>();
             T t = finish(reinterpret_cast<A1>(sourceObject),
                          result, &retval1, &retval2);
-            std::auto_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
+            std::unique_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
             (*cb)(t, retval1, retval2);
         } catch (...) {
             // called from C, must not let exception escape
@@ -801,7 +803,7 @@ template<class T, class F, F *finish, class A1, class A3> struct GAsyncReady4<T,
             A3_t retval = boost::value_initialized<A3_t>();
             T t = finish(reinterpret_cast<A1>(sourceObject),
                          result, &retval, gerror);
-            std::auto_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
+            std::unique_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
             (*cb)(t, retval, gerror);
         } catch (...) {
             // called from C, must not let exception escape
@@ -821,7 +823,7 @@ template <class T, class F, F *finish, class A1> struct GAsyncReady3<T, F, finis
             GErrorCXX gerror;
             T t = finish(reinterpret_cast<A1>(sourceObject),
                          result, gerror);
-            std::auto_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
+            std::unique_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
             (*cb)(t, gerror);
         } catch (...) {
             // called from C, must not let exception escape
@@ -842,7 +844,7 @@ template<class F, F *finish, class A1> struct GAsyncReady3<void, F, finish, A1,
             GErrorCXX gerror;
             finish(reinterpret_cast<A1>(sourceObject),
                    result, gerror);
-            std::auto_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
+            std::unique_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
             (*cb)(gerror);
         } catch (...) {
             // called from C, must not let exception escape
@@ -862,7 +864,7 @@ template<class T, class F, F *finish, class A1> struct GAsyncReady2<T, F, finish
         try {
             T t = finish(reinterpret_cast<A1>(sourceObject),
                          result);
-            std::auto_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
+            std::unique_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
             (*cb)(t);
         } catch (...) {
             // called from C, must not let exception escape
@@ -882,7 +884,7 @@ template<class T, class F, F *finish> struct GAsyncReady2<T, F, finish, GAsyncRe
         try {
             GErrorCXX gerror;
             T t = finish(result, gerror);
-            std::auto_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
+            std::unique_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
             (*cb)(t, gerror);
         } catch (...) {
             // called from C, must not let exception escape
@@ -902,7 +904,7 @@ template<class F, F *finish, class A1> struct GAsyncReady2<void, F, finish, A1,
         try {
             finish(reinterpret_cast<A1>(sourceObject),
                    result);
-            std::auto_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
+            std::unique_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
             (*cb)();
         } catch (...) {
             // called from C, must not let exception escape
@@ -922,7 +924,7 @@ template<class F, F *finish> struct GAsyncReady2<void, F, finish, GAsyncResult *
         try {
             GErrorCXX gerror;
             finish(result, gerror);
-            std::auto_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
+            std::unique_ptr<CXXFunctionCB_t> cb(static_cast<CXXFunctionCB_t *>(userData));
             (*cb)(gerror);
         } catch (...) {
             // called from C, must not let exception escape
@@ -936,9 +938,9 @@ template<class F, F *finish> struct GAsyncReady2<void, F, finish, GAsyncResult *
  * first switch based on arity of the finish function, then on its type
  */
 #define SYNCEVO_GLIB_CALL_ASYNC_CXX(_prepare) \
-    GAsyncReadyCXX< boost::remove_pointer<typeof(_prepare ## _finish)>::type, \
+    GAsyncReadyCXX< boost::remove_pointer<BOOST_TYPEOF(_prepare ## _finish)>::type, \
                     & _prepare ## _finish, \
-                    boost::function_traits<boost::remove_pointer<typeof(_prepare ## _finish)>::type>::arity >
+                    boost::function_traits<boost::remove_pointer<BOOST_TYPEOF(_prepare ## _finish)>::type>::arity >
 
 /**
  * Macro for asynchronous methods which use a GAsyncReadyCallback to
@@ -1041,7 +1043,7 @@ template<> class GAsyncReadyDoneCXX<void>
     do { \
         bool done = false; \
         SYNCEVO_GLIB_CALL_ASYNC(_prepare, \
-                                GAsyncReadyDoneCXX<boost::function<typeof(_prepare ## _finish)>::result_type>::createCB(_res, _gerror, done), \
+                                GAsyncReadyDoneCXX<boost::function<BOOST_TYPEOF(_prepare ## _finish)>::result_type>::createCB(_res, _gerror, done), \
                                 _args); \
         GRunWhile(! boost::lambda::var(done)); \
     } while (false); \
