@@ -54,6 +54,8 @@ using namespace GDBusCXX;
 
 #endif
 
+#include <boost/typeof/typeof.hpp>
+
 #include <syncevo/Cmdline.h>
 #include <syncevo/SyncContext.h>
 #include <syncevo/SuspendFlags.h>
@@ -74,10 +76,10 @@ SE_BEGIN_CXX
 #undef e_contact_new_from_vcard
 extern "C" EContact *e_contact_new_from_vcard(const char *vcard)
 {
-    static typeof(e_contact_new_from_vcard) *impl;
+    static BOOST_TYPEOF(e_contact_new_from_vcard) *impl;
 
     if (!impl) {
-        impl = (typeof(impl))dlsym(RTLD_NEXT, "e_contact_new_from_vcard");
+        impl = (BOOST_TYPEOF(impl))dlsym(RTLD_NEXT, "e_contact_new_from_vcard");
     }
 
     // Old versions of EDS-DBus parse_changes_array() call
