@@ -24,7 +24,7 @@ import logging.config
 
 import twisted.web
 import twisted.python.log
-import twisted.web.error
+import twisted.web.resource
 from twisted.web import server, resource, http
 from twisted.internet import ssl, reactor
 from OpenSSL import SSL
@@ -40,7 +40,7 @@ timeout=100000
 
 class ChainedOpenSSLContextFactory(ssl.DefaultOpenSSLContextFactory):
     def __init__(self, privateKeyFileName, certificateChainFileName,
-                 sslmethod = SSL.SSLv3_METHOD):
+                 sslmethod = SSL.TLSv1_METHOD):
         """
         @param privateKeyFileName: Name of a file containing a private key
         @param certificateChainFileName: Name of a file containing a certificate chain
@@ -359,7 +359,7 @@ class SyncMLPost(resource.Resource):
                     return server.NOT_DONE_YET
             # fallback when session not found
             logger.error("unknown session %s => 404 error", sessionid)
-            page = twisted.web.error.NoResource(message="The session %s was not found" % sessionid)
+            page = twisted.web.resource.NoResource(message="The session %s was not found" % sessionid)
             return page.render(request)
 
 class TwistedLogging(object):
